=============================
Django EL(Endless) Pagination
=============================

|  |pypi-pkg-version| |python-versions| |django-versions|  |pypi-status| |docs|
|  |travis-ci-status| |codecov|

Django EL(Endless) Pagination can be used to provide Twitter-style or
Digg-style pagination, with optional Ajax support and other features
like multiple or lazy pagination.

This app **django-el-pagination** forked from django-endless-pagination==2.0 (https://github.com/frankban/django-endless-pagination)
From version 3.0.0 drop support Django<1.8. For support Django<1.8 use django-endless-pagination==2.x.x

The initial idea, which has guided the development of this application,
is to allow pagination of web contents in `very few steps
<http://django-el-pagination.readthedocs.org/en/latest/start.html>`_.

**Documentation** is `available online
<http://django-el-pagination.readthedocs.org/>`_, or in the doc
directory of the project.

To file **bugs and requests**, please use
https://github.com/shtalinberg/django-el-pagination/issues.

The **source code** for this app is hosted at
https://github.com/shtalinberg/django-el-pagination.

Pull requests are welcome. See `Contributing Guide
<http://django-el-pagination.readthedocs.io/en/latest/contributing.html>`_.


.. |travis-ci-status| image:: https://travis-ci.org/shtalinberg/django-el-pagination.svg?branch=develop
   :target: https://travis-ci.org/shtalinberg/django-el-pagination
.. |docs| image:: https://readthedocs.org/projects/django-el-pagination/badge/?version=latest&style=flat
    :target: https://django-el-pagination.readthedocs.io/
.. |pypi-pkg-version| image:: https://img.shields.io/pypi/v/django-el-pagination.svg
   :target:  https://pypi.python.org/pypi/django-el-pagination/
.. |pypi-status| image:: https://img.shields.io/pypi/status/coverage.svg
    :target: https://pypi.python.org/pypi/django-el-pagination/
.. |python-versions| image:: https://img.shields.io/pypi/pyversions/django-el-pagination.svg
.. |django-versions| image:: https://img.shields.io/badge/django-1.8%20or%20newer-green.svg
.. |codecov| image:: https://codecov.io/gh/shtalinberg/django-el-pagination/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/shtalinberg/django-el-pagination   
